aboutsummaryrefslogtreecommitdiff
path: root/pthreads/pthread_cancel.c
diff options
context:
space:
mode:
Diffstat (limited to 'pthreads/pthread_cancel.c')
-rw-r--r--pthreads/pthread_cancel.c21
1 files changed, 13 insertions, 8 deletions
diff --git a/pthreads/pthread_cancel.c b/pthreads/pthread_cancel.c
index ae60b7293..bda3ab01d 100644
--- a/pthreads/pthread_cancel.c
+++ b/pthreads/pthread_cancel.c
@@ -8,10 +8,11 @@
*
* Pthreads-win32 - POSIX Threads Library for Win32
* Copyright(C) 1998 John E. Bossom
- * Copyright(C) 1999,2005 Pthreads-win32 contributors
- *
- * Contact Email: rpj@callisto.canberra.edu.au
- *
+ * Copyright(C) 1999,2012 Pthreads-win32 contributors
+ *
+ * Homepage1: http://sourceware.org/pthreads-win32/
+ * Homepage2: http://sourceforge.net/projects/pthreads4w/
+ *
* The current list of contributors is contained
* in the file CONTRIBUTORS included with the source
* code distribution. The list can also be seen at the
@@ -34,6 +35,10 @@
* 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA
*/
+#ifdef HAVE_CONFIG_H
+# include <config.h>
+#endif
+
#include "pthread.h"
#include "implement.h"
#include "context.h"
@@ -55,12 +60,12 @@ ptw32_cancel_callback (ULONG_PTR unused)
}
/*
- * ptw32_RegisterCancelation() -
+ * ptw32_Registercancellation() -
* Must have args of same type as QueueUserAPCEx because this function
* is a substitute for QueueUserAPCEx if it's not available.
*/
DWORD
-ptw32_RegisterCancelation (PAPCFUNC unused1, HANDLE threadH, DWORD unused2)
+ptw32_Registercancellation (PAPCFUNC unused1, HANDLE threadH, DWORD unused2)
{
CONTEXT context;
@@ -155,10 +160,10 @@ pthread_cancel (pthread_t thread)
/*
* If alertdrv and QueueUserAPCEx is available then the following
* will result in a call to QueueUserAPCEx with the args given, otherwise
* this will result in a call to ptw32_RegisterCancelation and only
* the threadH arg will be used.
*/
- ptw32_register_cancelation ((PAPCFUNC)ptw32_cancel_callback, threadH, 0);
+ ptw32_register_cancellation ((PAPCFUNC)ptw32_cancel_callback, threadH, 0);
ptw32_mcs_lock_release (&stateLock);
ResumeThread (threadH);
}
@@ -155,10 +160,10 @@ pthread_cancel (pthread_t thread)
* If alertdrv and QueueUserAPCEx is available then the following
* will result in a call to QueueUserAPCEx with the args given, otherwise
- * this will result in a call to ptw32_RegisterCancelation and only
+ * this will result in a call to ptw32_Registercancellation and only
* the threadH arg will be used.
*/